beaker v0.0.4

Modules summary

Beaker

Beaker is the parent application that will start all the different Beaker metric applications

Beaker.Counter

Beaker.Counter is a signed bi-directional integer counter. It can keep track of integers and increment and decrement them

Beaker.Gauge

Beaker.Gauge is a simple gauge. It’s a metric where a value can be set and retrieved

Beaker.Router

Beaker.Router is a router for Beaker integration into Phoenix. Importantly, it is NOT the entry point to Beaker from a Phoenix app. Instead, that should be Beaker.Web

Beaker.Router.Helpers

Module with named helpers generated from Beaker.Router

Beaker.TimeSeries

Beaker.TimeSeries is a simple time series. It’s a metric that keeps track of values over time when sampled