Beaker is the parent application that will start all the different Beaker metric applications
Beaker
Beaker.Counter is a signed bi-directional integer counter. It can keep track of integers and increment and decrement them
Beaker.Counter
Beaker.Gauge is a simple gauge. It’s a metric where a value can be set and retrieved
Beaker.Gauge